### Pytest Share HDF
![Tests](https://github.com/atharva-2001/pytest_share_hdf/actions/workflows/tests.yml/badge.svg)<br>
Pytest plugin to save references to an HDF file and then retrieve them for comparison with test results.